Index: src/uk/me/parabola/mkgmap/combiners/GmapiBuilder.java
===================================================================
--- src/uk/me/parabola/mkgmap/combiners/GmapiBuilder.java	(revision 4806)
+++ src/uk/me/parabola/mkgmap/combiners/GmapiBuilder.java	(working copy)
@@ -58,8 +58,15 @@
 
 	private String typFile;
 
+	private final  boolean forceWrite;
+
 	public GmapiBuilder(Map<String, Combiner> combinerMap) {
+		this(combinerMap, true);
+	}
+
+	public GmapiBuilder(Map<String, Combiner> combinerMap, boolean forceWrite) {
 		this.combinerMap = combinerMap;
+		this.forceWrite = forceWrite;
 	}
 
 	/**
@@ -157,7 +164,7 @@
 		unzipImg(srcImgName, destDir);
 	}
 
-	private static void unzipImg(String srcImgName, Path destDir) throws IOException {
+	private void unzipImg(String srcImgName, Path destDir) throws IOException {
 		FileSystem fs = ImgFS.openFs(srcImgName);
 		for (DirectoryEntry ent : fs.list()) {
 			String fullname = ent.getFullName();
@@ -168,7 +175,9 @@
 					continue;
 
 				Files.createDirectories(destDir);
-				copyToFile(f, destDir.resolve(name));
+				Path out = destDir.resolve(name);
+				if (forceWrite || Files.notExists(out) || Files.isWritable(out))
+					copyToFile(f, out);
 			}
 		}
 	}
Index: src/uk/me/parabola/mkgmap/main/Main.java
===================================================================
--- src/uk/me/parabola/mkgmap/main/Main.java	(revision 4806)
+++ src/uk/me/parabola/mkgmap/main/Main.java	(working copy)
@@ -706,10 +706,11 @@
 		boolean indexOpt = args.exists("index");
 		boolean gmapsuppOpt = args.exists("gmapsupp");
 		boolean tdbOpt = args.exists("tdbfile");
-		boolean gmapiOpt = args.exists("gmapi");
+		boolean gmapiOpt = args.exists("gmapi") || args.exists("gmapi-minimal"); 
+		boolean forceWriteGmapi = args.exists("gmapi"); 
 		boolean nsisOpt = args.exists("nsis");
 
-		for (String opt : Arrays.asList("gmapi", "nsis")) {
+		for (String opt : Arrays.asList("gmapi", "nsis", "gmapi-minimal")) {
 			if (!createTdbFiles && args.exists(opt)) {
 				throw new ExitException("Options --" + opt  + " and --no-tdbfiles are mutually exclusive");
 			}
@@ -729,7 +730,7 @@
 			addCombiner("mdx", new MdxBuilder());
 		}
 		if (gmapiOpt) {
-			addCombiner("gmapi", new GmapiBuilder(combinerMap));
+			addCombiner("gmapi", new GmapiBuilder(combinerMap, forceWriteGmapi));
 		}
 		if (nsisOpt) {
 			addCombiner("nsis", new NsisBuilder(combinerMap));
